@@ -7,8 +7,7 @@ import matplotlib.pyplot as plt
 import matplotlib.colors as mcolors
 from IPython import display
 from .logger import Logger
-_log = Logger("Log")
-
+_log = Logger(__file__)
 
 class DeferredCall(object):
     """
@@ -336,6 +335,8 @@ def figure( row_size : int = 5, col_size : int = 4, col_nums : int = 5, **fig_kw
     """   
     return DynamicFig( row_size=row_size, col_size=col_size, col_nums=col_nums, **fig_kwargs ) 
 
+
+
 # ----------------------------------------------------------------------------------
 # color management
 # ----------------------------------------------------------------------------------
